@@ -24,7 +24,7 @@
 #
 # NOTES:
 #
-# $Id: GFForm.py 7824 2005-08-11 03:20:07Z jamest $
+# $Id: GFForm.py 7983 2005-09-24 09:52:49Z reinhard $
 
 import sys
 import string
@@ -286,7 +286,7 @@ class GFForm(GRootObj, GFObj, events.EventAware):
     """
     
     if object._type == 'GFField':
-      gDebug (5, "GFField was passed to 'findFocus'.")
+      assert gDebug (5, "GFField was passed to 'findFocus'.")
       try:
         object = object._entryList[0]
       except IndexError:
@@ -350,12 +350,12 @@ class GFForm(GRootObj, GFObj, events.EventAware):
 
     # cannot change focus to same entry
     if widget == self._currentEntry:
-      gDebug (5, "Current entry did not change from %s" % widget)
+      assert gDebug (5, "Current entry did not change from %s" % widget)
       return
 
     cen = self._currentEntry is not None and self._currentEntry.name or '-'
     win = widget is not None and widget.name or '-'
-    gDebug (5, "Changing focus from %s (%s) to %s (%s)" % \
+    assert gDebug (5, "Changing focus from %s (%s) to %s (%s)" % \
                (self._currentEntry, cen, widget, win))
 
     try:
@@ -422,7 +422,7 @@ class GFForm(GRootObj, GFObj, events.EventAware):
       if blockChange:
         self.refreshDisplay(self._currentBlock)
 
-      gDebug (5, "Updating entries old: %s, new: %s" % \
+      assert gDebug (5, "Updating entries old: %s, new: %s" % \
                  (oldEntry, self._currentEntry))
 
       self.dispatchEvent('updateENTRY', oldEntry, _form=self)
@@ -444,13 +444,15 @@ class GFForm(GRootObj, GFObj, events.EventAware):
           self._currentBlock.processTrigger('Post-FocusIn', ignoreAbort=False)
         if pageChange:
           self._currentPage.processTrigger('Post-FocusIn', ignoreAbort=False)
+        if blockChange or pageChange:
+          self._instance.updateStatus (self)
 
-      gDebug (5, "calling refreshUIEvents ()")
+      assert gDebug (5, "calling refreshUIEvents ()")
       self.refreshUIEvents()
-      gDebug (5, "CurrentEntry is %s" % self._currentEntry)
+      assert gDebug (5, "CurrentEntry is %s" % self._currentEntry)
 
     except AbortRequest, t:
-      gDebug (5, "Trigger Error!")
+      assert gDebug (5, "Trigger Error!")
       message = _("Trigger Exception :\n") + t.message
 
     return message
@@ -473,10 +475,11 @@ class GFForm(GRootObj, GFObj, events.EventAware):
       self._currentBlock.newRecord()
 
 
-  #---------------------------------------------------------------------------
-  # Delete the actual record.
-  #---------------------------------------------------------------------------
-  def deleteRecord(self):
+  # --------------------------------------------------------------------------
+  # Delete the current record.
+  # --------------------------------------------------------------------------
+
+  def deleteRecord (self):
     """
     Deletes the actual record.
     """
@@ -485,6 +488,19 @@ class GFForm(GRootObj, GFObj, events.EventAware):
       self.refreshUIEvents()
 
 
+  # --------------------------------------------------------------------------
+  # Undelete the current record.
+  # --------------------------------------------------------------------------
+
+  def undeleteRecord (self):
+    """
+    Undeletes the actual record.
+    """
+    if not self.readonly:
+      self._currentBlock.undeleteRecord()
+      self.refreshUIEvents()
+
+
   #---------------------------------------------------------------------------
   # Check all blocks in the form whether they are saved (committed) or not.
   #---------------------------------------------------------------------------
@@ -540,7 +556,7 @@ class GFForm(GRootObj, GFObj, events.EventAware):
       block.processRollback()
       for entry in block._entryList:
         if hasattr(entry, 'queryDefault'):
-          gDebug (5, "%s will be set to %s" % (entry.name, entry.queryDefault))
+          assert gDebug (5, "%s will be set to %s" % (entry.name, entry.queryDefault))
           entry.setValue(entry.queryDefault)
 
     # If Enter-Query is hit once, enter query mode
@@ -641,7 +657,7 @@ class GFForm(GRootObj, GFObj, events.EventAware):
     @return: None if all went well, error message otherwise
     """
 
-    gEnter (4)
+    assert gEnter (4)
 
     self.endEditing ()
     if self.readonly:
@@ -662,18 +678,18 @@ class GFForm(GRootObj, GFObj, events.EventAware):
           self.processTrigger ('Pre-Commit', ignoreAbort = False)
 
         except AbortRequest:
-          gDebug (5, "Trigger form Pre-Commit threw a AbortRequest!")
+          assert gDebug (5, "Trigger form Pre-Commit threw a AbortRequest!")
           message = u_("Form trigger returned error")
 
 
         # Process the commit on all blocks
         for block in self._logic._blockList:
-          gDebug (5, "Saving %s" % block.name)
+          assert gDebug (5, "Saving %s" % block.name)
           try:
             block.processCommit ()
 
           except AbortRequest:
-            gDebug (5, "Trigger block Pre-Commit threw a AbortRequest!")
+            assert gDebug (5, "Trigger block Pre-Commit threw a AbortRequest!")
             message = u_("Block trigger returned error")
             # jump to offending block
             newBlock = block
@@ -688,12 +704,16 @@ class GFForm(GRootObj, GFObj, events.EventAware):
           for conn in self.__getConnections ().values ():
             conn.commit ()
 
-        finally:
+        except:
           # Make sure the block is in consistent state again; this has to be
           # done in any case if the processCommit was successful, even if the
-          # connection commit failed - thus the "finally" here.
+          # connection commit failed!
           for block in self._logic._blockList:            
-            block.finalizeCommit ()
+            block.finalizeCommit (False)
+          raise
+
+        for block in self._logic._blockList:            
+          block.finalizeCommit (True)
 
         # Execute Post-Commit-Trigger for each block
         for block in self._logic._blockList:
@@ -721,7 +741,7 @@ class GFForm(GRootObj, GFObj, events.EventAware):
         self.findAndChangeFocus (newBlock)
       self.dispatchEvent ('endWAIT', _form = self)
 
-    gLeave (4)
+    assert gLeave (4)
 
     return message
 
@@ -960,7 +980,7 @@ class GFForm(GRootObj, GFObj, events.EventAware):
     """
     block = self._currentBlock
     if not block:
-      gDebug(5,'No current block - cannot refresh UI')
+      assert gDebug(5,'No current block - cannot refresh UI')
       return
 
     dispatchEvent = self.dispatchEvent
@@ -981,9 +1001,7 @@ class GFForm(GRootObj, GFObj, events.EventAware):
       dispatchEvent('canENTERQUERY')
       dispatchEvent('cannotCANCELQUERY')
       dispatchEvent('cannotEXECQUERY')
-##      dispatchEvent('canNEXTRECORD')
 
-      # TODO: There should probably be some tests here....
       if not self.isSaved():
         dispatchEvent('canCOMMIT')
       else:
@@ -991,7 +1009,6 @@ class GFForm(GRootObj, GFObj, events.EventAware):
 
       dispatchEvent('canROLLBACK')
       dispatchEvent('canJUMPPROMPT')
-      dispatchEvent('canNEWRECORD')
       dispatchEvent('canMARKFORDELETE')
 
       if block._resultSet.isFirstRecord():
@@ -1002,17 +1019,31 @@ class GFForm(GRootObj, GFObj, events.EventAware):
         dispatchEvent('canFIRSTRECORD')
 
       if block._resultSet.isLastRecord():
-        dispatchEvent('cannotLASTRECORD')
         if block._resultSet.current.isEmpty():
           dispatchEvent('cannotNEXTRECORD')
-          dispatchEvent('cannotNEWRECORD')
         else:
-          dispatchEvent('canNEWRECORD')
+          dispatchEvent('canNEXTRECORD')
+        dispatchEvent('cannotLASTRECORD')
       else:
         dispatchEvent('canNEXTRECORD')
         dispatchEvent('canLASTRECORD')
         dispatchEvent('canNEWRECORD')
 
+      if block._resultSet.current.isEmpty():
+        dispatchEvent('cannotNEWRECORD')
+      else:
+        dispatchEvent('canNEWRECORD')
+
+      if block._resultSet.current.isDeleted () \
+          or block._resultSet.current.isVoid ():
+        dispatchEvent('cannotMARKFORDELETE')
+        dispatchEvent('canUNDELETE')
+        dispatchEvent('beginMARKFORDELETE')
+      else:
+        dispatchEvent('endMARKFORDELETE')
+        dispatchEvent('canMARKFORDELETE')
+        dispatchEvent('cannotUNDELETE')
+
 
   #---------------------------------------------------------------------------
   # Called whenever an event source has requested that the
