@@ -19,7 +19,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: GFInstance.py 7811 2005-08-09 18:30:12Z reinhard $
+# $Id: GFInstance.py 7985 2005-09-24 12:51:30Z reinhard $
 
 """
 GFInstance manages forms instances in a 1:N relationship. It sits between the
@@ -39,7 +39,7 @@ import dircache
 from gnue.forms.GFForm import *
 from gnue.forms.GFParser import loadFile
 from gnue.forms import VERSION
-from gnue.forms import GFKeyMapper
+from gnue.forms.input import GFKeyMapper
 from gnue.common.apps import i18n, errors
 from gnue.common.datasources import Exceptions, GConnections
 from gnue.common.datasources.GDataSource import getAppserverResource
@@ -76,10 +76,10 @@ class GFInstance (events.EventAware):
     # moduleName is here only for Designer to be able to pass it in
     #when debugging a form.
     
-    gEnter (4)
+    assert gEnter (4)
 
     # Configure event handling
-    gDebug (4, "Initializing event handling")
+    assert gDebug (4, "Initializing event handling")
 
     self.eventController = events.EventController ()
     events.EventAware.__init__ (self, self.eventController)
@@ -110,6 +110,7 @@ class GFInstance (events.EventAware):
                            # Data set manipulation
                            'requestNEWRECORD'    : self.newRecord,
                            'requestMARKFORDELETE': self.deleteRecord,
+                           'requestUNDELETE'     : self.undeleteRecord,
                            'requestCOMMIT'       : self.executeCommit,
                            'requestPRINTOUT'     : self.executePrintout,
                            'requestROLLBACK'     : self.executeRollback,
@@ -154,13 +155,13 @@ class GFInstance (events.EventAware):
 
     # Construct an instance of the UI driver if an UI module is available
     if self._uimodule is not None:
-      gDebug (4, "Initializing user interface driver")
+      assert gDebug (4, "Initializing user interface driver")
       self._uiinstance = self._uimodule.GFUserInterface (self.eventController,
                                        disableSplash   = self._disableSplash,
                                        parentContainer = self._parentContainer,
                                        moduleName = moduleName)
 
-    gLeave (4)
+    assert gLeave (4)
 
 
   # ---------------------------------------------------------------------------
@@ -294,19 +295,19 @@ class GFInstance (events.EventAware):
 
   def activate (self):
 
-    gEnter (4)
+    assert gEnter (4)
 
     # Initialize all the forms loaded into memory
-    gDebug (4, "Initializing form objects")
+    assert gDebug (4, "Initializing form objects")
 
     for formObject in self._formsDictionary.values ():
       formObject.phaseInit ()
 
-    gDebug (4, "Initializing user interface driver object")
+    assert gDebug (4, "Initializing user interface driver object")
     self._uiinstance.initialize ()
 
     # Build the UIs for all the forms
-    gDebug (4, "Building forms")
+    assert gDebug (4, "Building forms")
     for dialog in self._formsDictionary.keys ():
       self.buildForm (dialog)
 
@@ -317,19 +318,19 @@ class GFInstance (events.EventAware):
       # we assume a dialog to be modal by definition and that program execution
       # stops here until the dialog get's closed. So do *not* enter another
       # main loop
-      gDebug (4, "Activating main form as dialog")
+      assert gDebug (4, "Activating main form as dialog")
       self.activateForm ('__main__', modal = True)
 
     else:
-      gDebug (4, "Activating main form")
+      assert gDebug (4, "Activating main form")
       self.activateForm ('__main__')
 
-      gDebug (4, "Startup complete")
-      gDebug (4, "Entering main loop")
+      assert gDebug (4, "Startup complete")
+      assert gDebug (4, "Entering main loop")
       self._uiinstance.mainLoop ()
-      gDebug (4, "Returning from main loop")
+      assert gDebug (4, "Returning from main loop")
 
-    gLeave (4)
+    assert gLeave (4)
 
 
   # ---------------------------------------------------------------------------
@@ -338,7 +339,7 @@ class GFInstance (events.EventAware):
 
   def activateForm (self, formName = '__main__', parameters = {}, modal = 0):
 
-    gEnter (4)
+    assert gEnter (4)
 
     form = self._formsDictionary [formName]
 
@@ -349,17 +350,21 @@ class GFInstance (events.EventAware):
       raise errors.ApplicationError, \
          u_("There are no navigable widgets in this form. Unable to display.")
 
+    assert gDebug (4, "Processing activation trigger")
     form.processTrigger ('On-Activation')
 
     # First set the current entry to be focused and up to date before
     # displaying the real UI form. 
+    assert gDebug (4, "Initial display setup")    
     form.refreshDisplay (form)
     self.updateStatus (form)
 
+    assert gDebug (4, "Setting initial focus")    
     self.dispatchEvent ('gotoENTRY', object = form._currentEntry, _form = form)
+    assert gDebug (4, "Activating form")    
     self._uiinstance.activateForm (formName, modal)
 
-    gLeave (4)
+    assert gLeave (4)
 
 
   # ---------------------------------------------------------------------------
@@ -912,7 +917,7 @@ class GFInstance (events.EventAware):
   # Mark a record for deletion
   # ---------------------------------------------------------------------------
 
-  def deleteRecord(self, event):
+  def deleteRecord (self, event):
     """
     Tells the form to mark a record for delete
     """
@@ -928,6 +933,19 @@ class GFInstance (events.EventAware):
       self.updateRecordStatus (event._form)
 
 
+  # ---------------------------------------------------------------------------
+  # Unmark a record for deletion
+  # ---------------------------------------------------------------------------
+
+  def undeleteRecord (self, event):
+    """
+    Tells the form to mark a record for delete
+    """
+
+    event._form.undeleteRecord ()
+    self.updateRecordStatus (event._form)
+
+
   # ---------------------------------------------------------------------------
   # Tells the form to create a new record
   # ---------------------------------------------------------------------------
@@ -1172,14 +1190,15 @@ class GFInstance (events.EventAware):
     if not event._form.endEditing ():
       return
 
-    message = event._form.commit ()
-    if message:
-      self.displayMessageBox (message, 'Error')
-      gDebug(4,message)
-      return
+    try:
+      message = event._form.commit ()
+      if message:
+        self.displayMessageBox (message, 'Error')
+        assert gDebug(4,message)
 
-    self._entryUpdated (event._form)
-    event._form.refreshDisplay (event._form._currentBlock)
+    finally:
+      self._entryUpdated (event._form)
+      event._form.refreshDisplay (event._form._currentBlock)
 
 
   # ---------------------------------------------------------------------------
