@@ -19,12 +19,12 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: GFBlock.py 7828 2005-08-12 14:46:55Z reinhard $
+# $Id: GFBlock.py 7983 2005-09-24 09:52:49Z reinhard $
 """
 Classes making up the Block object
 """
 
-__revision__ = "$Id: GFBlock.py 7828 2005-08-12 14:46:55Z reinhard $"
+__revision__ = "$Id: GFBlock.py 7983 2005-09-24 09:52:49Z reinhard $"
 
 from gnue.forms.GFObjects.GFDataSource import GFDataSource
 
@@ -67,15 +67,18 @@ class GFBlock(GFContainer, events.EventAware):
     self._fieldMap = {}
     self._fieldList = []
 
-    # True if the block has been saved but the transaction has not yet been
-    # committed. The block will still return True on isPending().
+    # Current top of visible portion
+    self.__visibleStart = 0
+
+    # Are we scrolling the visible portion along with record movement?
+    self.__scrolling = False
 
     #
     # Trigger exposure
     #
     self._validTriggers = {
-##                  'ON-SWITCH':      'On-Switch',    ## Deprecated
                   'ON-NEWRECORD':   'On-NewRecord',
+                  'ON-RECORDLOADED':'On-RecordLoaded',
                   'PRE-COMMIT':     'Pre-Commit',
                   'POST-COMMIT':    'Post-Commit',
                   'PRE-QUERY':      'Pre-Query',
@@ -229,6 +232,7 @@ class GFBlock(GFContainer, events.EventAware):
         'dsResultSetActivated': self.__dsResultSetActivated,
         'dsResultSetChanged'  : self.__dsResultSetActivated, # sic!
         'dsCursorMoved'       : self.__dsCursorMoved,
+        'dsRecordInserted'    : self.__dsRecordInserted,
         'dsRecordLoaded'      : self.__dsRecordLoaded,
         'dsRecordTouched'     : self.__dsRecordTouched,
         'dsCommitInsert'      : self.__dsCommitInsert,
@@ -279,12 +283,28 @@ class GFBlock(GFContainer, events.EventAware):
     # Blocks can't cope with current record #-1
     recno = self._resultSet.getRecordNumber ()
     if recno != -1:
-      self.switchRecord (recno - self._currentRecord)
+      if self.__scrolling:
+        self.switchRecord (0)
+      else:
+        self.switchRecord (recno - self._currentRecord)
+
+  # ---------------------------------------------------------------------------
+
+  def __dsRecordInserted (self, event):
+    self._initializingRecord = event.record
+    oldmode = self.mode
+    self.mode = 'init'
+    self.processTrigger ('ON-NEWRECORD')
+    self.mode = oldmode
 
   # ---------------------------------------------------------------------------
 
   def __dsRecordLoaded (self, event):
-    pass        # TODO: define a trigger for this
+    self._initializingRecord = event.record
+    oldmode = self.mode
+    self.mode = 'init'
+    self.processTrigger ('ON-RECORDLOADED')
+    self.mode = oldmode
 
   # ---------------------------------------------------------------------------
 
@@ -355,6 +375,8 @@ class GFBlock(GFContainer, events.EventAware):
   #
   # deleteRecord
   #
+  # FIXME: This is a duplicate of GDataSource.__trigger_delete. Do we really
+  # need both?
   def deleteRecord(self):
     """
     Doesn't really delete the record but marks it for
@@ -362,6 +384,15 @@ class GFBlock(GFContainer, events.EventAware):
     """
     self._resultSet.current.delete()
 
+  #
+  # undeleteRecord
+  #
+  def undeleteRecord(self):
+    """
+    Removes the delete mark from the record
+    """
+    self._resultSet.current.undelete()
+
   #
   # isEmpty()
   #
@@ -382,7 +413,20 @@ class GFBlock(GFContainer, events.EventAware):
     """
     Moves the proper record into editing position
     """
-    self._currentRecord = self._resultSet.getRecordNumber()
+    newRecord = self._resultSet.getRecordNumber ()
+    newRecordCount = self._resultSet.getRecordCount ()
+
+    self.__visibleStart += newRecord - self._currentRecord - adjustment
+    if self.__visibleStart > newRecord:
+      self.__visibleStart = newRecord
+    if self.__visibleStart < newRecord - self._rows + 1:
+      self.__visibleStart = newRecord - self._rows + 1
+    if self.__visibleStart < 0:
+      self.__visibleStart = 0
+
+    self._currentRecord = newRecord
+    self._recordCount = newRecordCount
+
     for field in self._fieldList:
       field.gotNewCurrentRecord()
       for entry in field._entryList:
@@ -394,7 +438,8 @@ class GFBlock(GFContainer, events.EventAware):
 
     # Adjusting scrollbars
     for sb in self._scrollbars:
-      sb.adjustScrollbar(self._currentRecord, self._recordCount)
+      sb.adjustScrollbar (self.__visibleStart,
+          max (self._recordCount, self.__visibleStart + self._rows))
 
   #
   # newRecord
@@ -415,8 +460,6 @@ class GFBlock(GFContainer, events.EventAware):
 
       # Focus in
       self.processTrigger('PRE-FOCUSIN')
-      self.processTrigger('ON-NEWRECORD')
-
       self.processTrigger('POST-FOCUSIN')
 
   def duplicateRecord(self, exclude=(), include=()):
@@ -503,16 +546,22 @@ class GFBlock(GFContainer, events.EventAware):
       raise "Invalid record number"
 
     if recordNumber != self._resultSet.getRecordNumber():
-      # Focus out
-      self.processTrigger('PRE-FOCUSOUT')
-      self.processTrigger('POST-FOCUSOUT')
+
+      if self._form._currentEntry._block == self:
+        # Focus out
+        self.processTrigger('PRE-FOCUSOUT')
+        self.processTrigger('POST-FOCUSOUT')
 
       if not self._resultSet.setRecord(recordNumber):
         self._resultSet.lastRecord()
 
-      # Focus in
-      self.processTrigger('PRE-FOCUSIN')
-      self.processTrigger('POST-FOCUSIN')
+      if self._form._currentEntry._block == self:
+        # Focus in
+        self.processTrigger('PRE-FOCUSIN')
+        self.processTrigger('POST-FOCUSIN')
+        # Move to correct record in grid
+        self._form.findAndChangeFocus (self._form._currentEntry)
+        self._form._instance.updateRecordCounter (self._form)
 
 
   def jumpRecords(self, adjustment):
@@ -524,13 +573,60 @@ class GFBlock(GFContainer, events.EventAware):
       targetRecord = self._resultSet.getRecordCount()
 
     self.jumpRecord(targetRecord)
-    self._form._instance.updateRecordCounter(self._form)
+
+
+  # ---------------------------------------------------------------------------
+  # Scroll a given number of records
+  # ---------------------------------------------------------------------------
+
+  def scrollRecords (self, adjustment):
+    """
+    Scroll the given number of records.
+    """
+
+    self.scrollToRecord (self.__visibleStart + adjustment)
+
+
+  # ---------------------------------------------------------------------------
+  # Scroll to given record number
+  # ---------------------------------------------------------------------------
+
+  def scrollToRecord (self, position):
+    """
+    Scrolls the block to the given position.
+
+    The record number given in position will become the first visible record.
+    """
+
+    # First, scroll as far as possible without moving the record pointer
+    newVisibleStart = position
+
+    if newVisibleStart > self._currentRecord:
+      newVisibleStart = self._currentRecord
+    if newVisibleStart < self._currentRecord - self._rows + 1:
+      newVisibleStart = self._currentRecord - self._rows + 1
+
+    if newVisibleStart != self.__visibleStart:
+      self.switchRecord (self.__visibleStart - newVisibleStart)
+
+    # Now we have to move the record pointer to keep it in the visible portion
+    if position != self.__visibleStart:
+      self.__scrolling = True
+      try:
+        self.jumpRecords (position - self.__visibleStart)
+      finally:
+        self.__scrolling = False
+    else:
+      # If we didn't move the cursor, we have to update cursor position in UI
+      if self._form._currentEntry._block == self:
+        self._form.findAndChangeFocus (self._form._currentEntry)
+
 
   #
   # processCommit
   #
   def processCommit(self):
-    gDebug (4, "processing commit on block %s"%self.name,1)
+    assert gDebug (4, "processing commit on block %s"%self.name,1)
 
     self.mode='commit'
 
@@ -542,11 +638,11 @@ class GFBlock(GFContainer, events.EventAware):
   #
   # Called after the commit on the backend is through.
   #
-  def finalizeCommit (self):
+  def finalizeCommit (self, commit):
 
     # Synchronize backend -> resultset -> UI
     if self._getMasterBlock () is None:
-      self._dataSourceLink.requeryAll (True)
+      self._dataSourceLink.requeryAll (commit)
 
     # Our recordCount might have changed if records were deleted
     self._recordCount = self._resultSet.getRecordCount()
@@ -555,9 +651,6 @@ class GFBlock(GFContainer, events.EventAware):
     if not self._recordCount:
       self.newRecord()
 
-    # The block is not uncommitted any more
-    self.__uncommitted = False
-
     self.mode='normal'
 
 
@@ -686,22 +779,29 @@ class GFBlock(GFContainer, events.EventAware):
 
     # Adjusting scrollbars
     for sb in self._scrollbars:
-      sb.adjustScrollbar(self._currentRecord, self._recordCount)
+      sb.adjustScrollbar (self._currentRecord, self._recordCount)
 
 
-  def registerScrollbar(self, sb):
-    self._scrollbars.append(sb)
+  def registerScrollbar (self, sb):
+    self._scrollbars.append (sb)
+
 
   # ---------------------------------------------------------------------------
   # Call a datasource's function
   # ---------------------------------------------------------------------------
 
+  # FIXME: This is a duplicate of GDataSource.__trigger_call. Do we really need
+  # both?
   def callFunction (self, name, parameters):
     try:
-      self.__uncommitted = True
+      # Remember the current record; the record pointer is not reliable between
+      # postAll and requeryAll!
+      current = self._resultSet.current
       self._dataSourceLink.postAll ()
-      res = self._resultSet.current.call (name, parameters)
-      self._dataSourceLink.requeryAll (False)
+      try:
+        res = current.call (name, parameters)
+      finally:
+        self._dataSourceLink.requeryAll (False)
     finally:
       self.switchRecord (0)
 
@@ -712,9 +812,10 @@ class GFBlock(GFContainer, events.EventAware):
   # Update the current datasource's record set
   # ---------------------------------------------------------------------------
 
+  # FIXME: This is a duplicate of GDataSource.__trigger_update. Do we really
+  # need both?
   def updateCurrentRecordSet (self):
     try:
-      self.__uncommitted = True
       self._dataSourceLink.postAll ()
       self._dataSourceLink.requeryAll (False)
     finally:
