@@ -32,7 +32,7 @@ Component support (bonobo for gtk2, ole for win32, etc.)
 
 from gnue.common import events
 from GFValue import GFValue
-from gnue.forms import GFDisplayHandler
+from gnue.forms.input import displayHandlers
 
 #
 #GFComponent
@@ -89,7 +89,7 @@ class GFComponent(GFValue):
 
     self._navigable = False # self.navigable
                                         
-    self._displayHandler = GFDisplayHandler.ComponentDisplayHandler(self,
+    self._displayHandler = displayHandlers.Component(self,
                               self._form._instance.eventController,
                               self.subEventHandler)
 
