@@ -28,9 +28,8 @@ The primary data entry widget in forms
 # NOTES:
 #
 
-from gnue.forms import GFDisplayHandler
+from gnue.forms.input import displayHandlers
 from GFTabStop import GFTabStop
-import string
 
 ############################################################
 # GFEntry
@@ -123,33 +122,11 @@ class GFEntry(GFTabStop):
     self._inputmask = hasattr(self,'inputmask') and self.inputmask or ""
     self._displaymask = hasattr(self,'displaymask') and self.displaymask or ""
 
-    # TODO: Conversion: I'm torn... does this go here or in GFField??
-    # Create an appropriate display handler
-    if self.style == 'checkbox':
-      self._displayHandler = GFDisplayHandler.CheckboxDisplayHandler(self,
-               self._form._instance.eventController, self.subEventHandler)
-    elif self.style == 'dropdown':
-      self._displayHandler = GFDisplayHandler.DropdownDisplayHandler(self,
-               self._form._instance.eventController, self.subEventHandler)
-    elif self.style == 'listbox':
-      self._displayHandler = GFDisplayHandler.ListboxDisplayHandler(self,
-               self._form._instance.eventController, self.subEventHandler)
-    elif self.style == 'password':
-      self._displayHandler = GFDisplayHandler.PasswordDisplayHandler(self,
-               self._form._instance.eventController, self.subEventHandler,
-               self._displaymask, self._inputmask)
-    elif self._field.typecast == 'number':
-      self._displayHandler = GFDisplayHandler.NumberDisplayHandler(self,
-               self._form._instance.eventController, self.subEventHandler,
-               self._displaymask, self._inputmask)
-    elif self._field.typecast == 'date':
-      self._displayHandler = GFDisplayHandler.DateDisplayHandler(self,
-               self._form._instance.eventController, self.subEventHandler,
-               self._displaymask, self._inputmask)
-    else:
-      self._displayHandler = GFDisplayHandler.TextDisplayHandler(self,
-               self._form._instance.eventController, self.subEventHandler,
-               self._displaymask, self._inputmask)
+    # Associate a display handler with this instance
+    self._displayHandler = displayHandlers.factory(self,
+                             self._form._instance.eventController,
+                             self.subEventHandler,
+                             self._displaymask, self._inputmask)
 
     # Row settings
     if hasattr(self,'rows'):
@@ -184,13 +161,13 @@ class GFEntry(GFTabStop):
     return self._field.triggerSetValue(*args, **parms)
 
   def triggerSetHidden(self, value):
-    self.hidden = not not value # Force boolean
+    self.hidden = bool(value)
 
   def triggerGetHidden(self):
     return self.hidden
 
   def triggerSetNavigable(self, value):
-    self.navigable = not not value # Force boolean
+    self.navigable = bool(value)
 
   def triggerGetNavigable(self):
     return self.navigable
