@@ -274,6 +274,10 @@ class GFField(GFValue):
             value = self._block._queryValues[self]
           except KeyError:
             value = None
+
+    elif mode == 'init':
+      value = self._block._initializingRecord [self.field]
+
     else:
       if self._block._resultSet and self._block._resultSet.current:
         value = self._block._resultSet.current.getField(self.field)
@@ -343,6 +347,9 @@ class GFField(GFValue):
     if mode == 'query':
       self._block._queryValues[self] = value
 
+    elif mode == 'init':
+      self._block._initializingRecord [self.field] = value
+
     else:
       self._block.processTrigger('Pre-Change')
       self.processTrigger('Pre-Change')
@@ -358,13 +365,13 @@ class GFField(GFValue):
 ###        self.dispatchEvent('canCOMMIT')
 ###        self.dispatchEvent('canROLLBACK')
 
-    # If the field value has changed do to a trigger
-    # then update the UI
-    self._block._form.updateUIEntry(self)
+    # If the field value of the current record has changed, update the UI
+    if mode != 'init':                  # init doesn't affect current record!
+      self._block._form.updateUIEntry(self)
 
-    # If the field is a foreign key, move the result set to the selected value
-    if hasattr(self,'_GFField__fk_resultSet'):
-      self.__fk_resultSet.findRecord({self.fk_key: value})
+      # If the field is a foreign key, move the result set to the selected value
+      if hasattr(self,'_GFField__fk_resultSet'):
+        self.__fk_resultSet.findRecord({self.fk_key: value})
 
 
   # ---------------------------------------------------------------------------
@@ -437,7 +444,7 @@ class GFField(GFValue):
     # Remember the resultSet for later
     self.__fk_resultSet = resultSet
  
-    gDebug (5,'Created for DropDown: %s' % self._allowedValues)
+    assert gDebug (5,'Created for DropDown: %s' % self._allowedValues)
 
   def allowedValues(self):
     return (self._allowedValues, self._allowedValuesDescr)
