@@ -34,7 +34,7 @@ Logical image support
 
 from GFTabStop import GFTabStop
 from GFTabStop import GFTabStop
-from gnue.forms import GFDisplayHandler
+from gnue.forms.input import displayHandlers
 #
 #GFLabel
 #
@@ -91,9 +91,12 @@ class GFImage(GFTabStop):
 
     self._navigable = False # self.navigable
 
-    self._displayHandler = GFDisplayHandler.ImageDisplayHandler(self,
+    # print "Controller", self._form._instance.eventController
+    # print "Sub Handler", self.subEventHandler
+    # print displayHandlers.Image
+    self._displayHandler = displayHandlers.factory(self,
                               self._form._instance.eventController,
-                              self.subEventHandler)
+                              self.subEventHandler,None, None)
 
   # TODO: Conversion:  Does this belong here or not?
   def getValue(self, *args, **parms):
