@@ -19,7 +19,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: UIdriver.py 7774 2005-08-03 04:23:13Z jcater $
+# $Id: UIdriver.py 7929 2005-09-20 15:25:31Z johannes $
 
 import sys, os, dircache
 
@@ -167,9 +167,9 @@ class GFUserInterfaceBase (GRootObj, events.EventAware):
             raise ImportError, mesg
 
       except ImportError, mesg:
-        gDebug (1, "%s.widgets.%s doesn't appear to be a valid ui widget" \
+        assert gDebug (1, "%s.widgets.%s doesn't appear to be a valid ui widget" \
                    % (uiDriver, widgetName))
-        gDebug (1, ' --> %s' % mesg)
+        assert gDebug (1, ' --> %s' % mesg)
 
     self._uiFocusWidget = None
 
@@ -270,6 +270,7 @@ class GFUserInterfaceBase (GRootObj, events.EventAware):
       # Add to the cross refernce
       #
       self._gfObjToUIWidget [object] = uiWidget
+      object.uiWidget = uiWidget
 
       #
       # If the current object is a GFForm then add it to the
@@ -288,10 +289,10 @@ class GFUserInterfaceBase (GRootObj, events.EventAware):
       if not uiWidget.widgets == []:
         self._gfObjToToolkitWidgets [object] = uiWidget.widgets
 
-      gDebug (5, "Widget is %s" % uiWidget.widgets)
+      assert gDebug (5, "Widget is %s" % uiWidget.widgets)
 
     except KeyError:
-      gDebug(4, "KeyError in _buildUI")
+      assert gDebug(4, "KeyError in _buildUI")
 
 
   #############################################################################
@@ -384,12 +385,12 @@ class GFUserInterfaceBase (GRootObj, events.EventAware):
       record = block._resultSet.getRecord (currentRecord - (index - count))
       value  = handler.getDisplayFiller (record.getField (field.field))
 
-      gDebug (5, "UPD-ENTRY %s prior: '%s' (%s)" % (entry, value, count))
+      assert gDebug (5, "UPD-ENTRY %s prior: '%s' (%s)" % (entry, value, count))
       self._gfObjToUIWidget [entry].setValue (value, count)
 
     # Fill current spot
     value = handler.getDisplayFiller (entry.getValue ())
-    gDebug (5, "UPD-ENTRY %s current: '%s' (%s)" % (entry, value, index))
+    assert gDebug (5, "UPD-ENTRY %s current: '%s' (%s)" % (entry, value, index))
     self._gfObjToUIWidget [entry].setValue (value, index)
 
     # Fill trailing spots
@@ -412,7 +413,7 @@ class GFUserInterfaceBase (GRootObj, events.EventAware):
         else:
           value = handler.getDisplayFiller (rec.getField (field.field))
 
-        gDebug (5, "UPD-ENTRY %s trail: '%s' (%s)" % (entry, value, count))
+        assert gDebug (5, "UPD-ENTRY %s trail: '%s' (%s)" % (entry, value, count))
         self._gfObjToUIWidget [entry].setValue (value, count, cr <= lastRow)
 
       count += 1
@@ -427,7 +428,7 @@ class GFUserInterfaceBase (GRootObj, events.EventAware):
 
     index  = event.object._visibleIndex
     widget = self._gfObjToUIWidget [event.object]
-    gDebug (5, "UPD-ENTRY-ED %s '%s' %s" % (event.object, event.display, index))
+    assert gDebug (5, "UPD-ENTRY-ED %s '%s' %s" % (event.object, event.display, index))
     widget.setValue (event.display, index)
     widget.setCursorPosition (event.cursor, index)
 
@@ -442,7 +443,7 @@ class GFUserInterfaceBase (GRootObj, events.EventAware):
 
   def getClipboardContents (self, event):
 
-    gDebug (5, "Getting clipboard '%s'" % self.__clipboard)
+    assert gDebug (5, "Getting clipboard '%s'" % self.__clipboard)
     event.__result__ = "%s" % self.__clipboard
 
 
@@ -452,7 +453,7 @@ class GFUserInterfaceBase (GRootObj, events.EventAware):
 
   def setClipboardContents (self, event):
 
-    gDebug (5, "Setting clipboard '%s'" % event.text)
+    assert gDebug (5, "Setting clipboard '%s'" % event.text)
     self.__clipboard = "%s" % event.text
 
 
