@@ -28,7 +28,7 @@
 #
 
 from gnue.common.apps import GConfig
-from gnue.forms import GFKeyMapper
+from gnue.forms.input import GFKeyMapper
 import os
 
 _iconpath = GConfig.getInstalledBase('form_images', 'common_images')
@@ -184,7 +184,13 @@ for action in [
     UserAction(
        event="MARKFORDELETE",
        description=u_('Mark record for removal at next commit.'),
-       help=u_('Mark record for removal at next commit.') ),
+       help=u_('Mark record for removal at next commit.'),
+       canToggle='UNDELETE'),
+
+    UserAction(
+       event='UNDELETE',
+       description=u_("Unmark record for removal at next commit."),
+       help=u_("Unmark record for removal at next commit.") ),
 
     UserAction(
        event="NEXTBLOCK",
@@ -212,11 +218,11 @@ for action in [
        help=u_('Switch to query mode. Select Execute Query once your criteria has been entered.'),
        canToggle='CANCELQUERY' ),
 
-    UserAction(
-       event="ENTEREDIT",
-       description=u_('Switch to edit mode.  This will allow you to edit the current entries.'),
-       help=u_('Switch to edit mode.'),
-       canToggle='CANCELEDIT' ),
+#   UserAction(
+#      event="ENTEREDIT",
+#      description=u_('Switch to edit mode.  This will allow you to edit the current entries.'),
+#      help=u_('Switch to edit mode.'),
+#      canToggle='CANCELEDIT' ),
 
     UserAction(
        event="COPYQUERY",
