@@ -148,7 +148,8 @@ _DEFAULT_MENU =  (
        None,
        (u_('&Insert New Record'),"NEWRECORD"),
        None,
-       (u_('&Delete Current Record'),'MARKFORDELETE') ) ),
+       (u_('&Delete Current Record'),'MARKFORDELETE'),
+       (u_('&Undelete Current Record'),'UNDELETE') ) ),
 
    ( u_('&Navigation'), (
        (u_('&Next Entry'), "NEXTENTRY"),
