@@ -141,7 +141,7 @@ class ToolBar:
 
 _DEFAULT_TOOLBAR =  (
     (u_('Save Changes'), "COMMIT"),
-    (u_('Edit Current Record'),'ENTEREDIT'),
+    # (u_('Edit Current Record'),'ENTEREDIT'),
     None,
     (u_('Insert New Record'),"NEWRECORD"),
     (u_('Delete Current Record'),'MARKFORDELETE'),
