@@ -19,11 +19,12 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: UILoginHandler.py 6851 2005-01-03 20:59:28Z jcater $
+# $Id: UILoginHandler.py 7806 2005-08-09 17:21:10Z reinhard $
 
 import curses
 
 from gnue.common.datasources import GLoginHandler
+from gnue.forms.uidrivers.curses import dialogs
 
 # =============================================================================
 # This class implements a login handler for curses
@@ -35,10 +36,9 @@ class UILoginHandler (GLoginHandler.LoginHandler):
   # Get input for all fields listed in loginData
   # ---------------------------------------------------------------------------
 
-  def getLogin (self, loginData, error = None):
+  def _askLogin_ (self, title, fields):
 
-    (connection, description, fields) = loginData
+    dlg = dialogs.InputDialog (title, fields, self.uiDriver.attr)
 
-    text = u_('Login required for "%s"') % (description or connection)
-
-    return self.uiDriver.askLogin (text, fields, error)
+    dlg.run ()
+    return dlg.inputData
