@@ -19,12 +19,12 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: form.py 7494 2005-04-28 08:17:46Z johannes $
+# $Id: form.py 7863 2005-08-14 00:51:48Z jamest $
 
 import curses
 import string
 
-from gnue.forms.GFKeyMapper import KeyMapper
+from gnue.forms.input.GFKeyMapper import KeyMapper
 
 from gnue.forms.uidrivers._base import UIdriver as BaseDriver
 from gnue.forms.uidrivers._base.widgets._base import UIWidget
