@@ -19,7 +19,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: page.py 6851 2005-01-03 20:59:28Z jcater $
+# $Id: page.py 7494 2005-04-28 08:17:46Z johannes $
 
 import curses
 
@@ -47,7 +47,7 @@ class UIPage (UIWidget):
     (self.__x1, self.__y1, self.__x2, self.__y2) = event.parent.getCanvas ()
 
     self.__window = curses.newpad (self.__y2 - self.__y1, self.__x2 - self.__x1)
-    self.__window.keypad (True)
+    self.__window.keypad (1)
     self.__window.bkgd (' ', self._uiDriver.attr ['background'])
     self.__cursor = (0, 0)
 
