@@ -19,18 +19,22 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: scrollbar.py 6851 2005-01-03 20:59:28Z jcater $
+# $Id: scrollbar.py 7961 2005-09-22 04:24:33Z reinhard $
 
 from _base import UIHelper
 
 # =============================================================================
-# Scrollbar class
+# Scrollbar class (stub - no scrollbars for curses)
 # =============================================================================
 
 class UIScrollBar (UIHelper):
+
   def _init (self, index):
     pass
 
+  def adjustScrollbar (self, position, count):
+    pass
+
 # =============================================================================
 # Configuration data
 # =============================================================================
