@@ -19,10 +19,9 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: MenuBar.py 6885 2005-01-10 14:59:09Z johannes $
+# $Id: MenuBar.py 7936 2005-09-21 09:04:24Z johannes $
 
 import gtk
-import string
 
 from gnue.forms.uidrivers._commonGuiToolkit.MenuBar import MenuBar as Base
 
@@ -56,9 +55,7 @@ class MenuBar (Base):
   # ---------------------------------------------------------------------------
 
   def correctLabel (self, label):
-    # TODO: remove decode step, when gettext translations are send
-    # in unicode instead of local encoding
-    return string.replace (label, '&', '_')
+    return label.replace ('&', '_')
     
   # ---------------------------------------------------------------------------
   # Add a (sub)menu
@@ -127,7 +124,7 @@ class MenuBar (Base):
   def _selectHandler (self, menuItem, userAction):
 
     self.container._setStatusBar (userAction.description, None, None, None,
-                                  None, None, None)
+                                  None, None, None, procMsg = False)
 
 
   # ---------------------------------------------------------------------------
@@ -136,7 +133,8 @@ class MenuBar (Base):
 
   def _deselectHandler (self, menuItem, userAction):
 
-    self.container._setStatusBar ('', None, None, None, None, None, None)
+    self.container._setStatusBar ('', None, None, None, None, None, None,
+        procMsg = False)
 
 
   # ---------------------------------------------------------------------------
