@@ -19,7 +19,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: UIdriver.py 7551 2005-05-20 08:54:33Z johannes $
+# $Id: UIdriver.py 7936 2005-09-21 09:04:24Z johannes $
 
 import sys
 import string
@@ -115,7 +115,6 @@ class GFUserInterface (commonToolkit.GFUserInterface):
     if not self._disableSplash:
       self.splash = UISplashScreen ()
       self.splash.Show ()
-      gobject.timeout_add (1500, lambda splash: splash.destroy (), self.splash)
 
     self.font       = APPFONT
 
@@ -127,7 +126,7 @@ class GFUserInterface (commonToolkit.GFUserInterface):
 
     (self.textWidth, self.textHeight) = sr
 
-    gDebug (6, "Metrics %s x %s" % (self.textWidth, self.textHeight))
+    assert gDebug (6, "Metrics %s x %s" % (self.textWidth, self.textHeight))
 
     self.widgetWidth  = self.textWidth
     self.widgetHeight = self.textHeight
@@ -236,18 +235,18 @@ class GFUserInterface (commonToolkit.GFUserInterface):
 
   def getClipboardContents (self, event):
 
-    gDebug (6, "Retrieving clipboard contents")
+    assert gDebug (6, "Retrieving clipboard contents")
 
     widget = self._UIform.mainWindow.get_focus ()
     if isinstance (widget, gtk.TextView):
-      gDebug (6, "Clipboard is %s" % self._clipboard)
+      assert gDebug (6, "Clipboard is %s" % self._clipboard)
 
       tBuffer = widget.get_buffer ()
       pos = tBuffer.get_iter_at_mark (tBuffer.get_insert ())
       tBuffer.paste_clipboard (self._clipboard, pos, widget.get_editable())
 
     elif hasattr (widget, 'paste_clipboard'):
-      gDebug (6, "calling %s.paste_clipboard" % widget)
+      assert gDebug (6, "calling %s.paste_clipboard" % widget)
       widget.paste_clipboard ()
 
     event.__result__ = None
@@ -259,7 +258,7 @@ class GFUserInterface (commonToolkit.GFUserInterface):
 
   def setClipboardContents (self, event):
 
-    gDebug (6, "Setting clipboard contents")
+    assert gDebug (6, "Setting clipboard contents")
 
     widget = self._UIform.mainWindow.get_focus ()
     if isinstance (widget, gtk.TextView):
@@ -267,7 +266,7 @@ class GFUserInterface (commonToolkit.GFUserInterface):
       tBuffer.copy_clipboard (self._clipboard)
 
     if hasattr (widget, 'copy_clipboard'):
-      gDebug (6, "calling %s.copy_clipboard ()" % widget)
+      assert gDebug (6, "calling %s.copy_clipboard ()" % widget)
       widget.copy_clipboard ()
 
 
