@@ -19,9 +19,10 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: entry.py 7358 2005-04-12 19:44:17Z reinhard $
+# $Id: entry.py 7965 2005-09-22 08:36:05Z johannes $
 
 import gtk
+import gobject
 import math
 
 from gnue.common import events
@@ -39,10 +40,7 @@ class UIEntry (UIHelper):
     style    = gfObject.style
 
     if style == 'dropdown':
-      if self._useNewGTKAPI:
-        newWidget = self.__createDropDown (gfObject, event)
-      else:
-        newWidget = self.__createOldDropDown (gfObject, event)
+      newWidget = self.__createDropDown (gfObject, event)
 
     elif style == 'label':
       newWidget = self.__createLabel (gfObject, event)
@@ -64,43 +62,6 @@ class UIEntry (UIHelper):
     return newWidget
 
 
-  # ---------------------------------------------------------------------------
-  # Create a dropdown widget
-  # ---------------------------------------------------------------------------
-
-  def __createOldDropDown (self, gfObject, event):
-    newWidget = gtk.Combo ()
-    maxLen = hasattr (gfObject, 'maxLength') and gfObject.maxLength or 0
-    newWidget.entry.set_max_length (maxLen)
-    
-    newWidget._origAllowedValues = None
-    self._updateChoices (newWidget, gfObject)
-
-    # Enter does NOT open the popup list
-    newWidget.disable_activate ()
-
-    newWidget.set_size_request (self.itemWidth, self.itemHeight)
-    event.container.put (newWidget, self.itemX, self.itemY)
-    newWidget.show ()
-
-    if event.initialize:
-      self._addDefaultEventHandler (newWidget)
-      self._addFocusHandler (newWidget.entry, newWidget)
-      self._addDefaultEventHandler (newWidget.entry, newWidget)
-
-      entry = newWidget.entry
-      entry._insert_handler = entry.connect ('insert-text',
-                                             self.insertTextHandler,
-                                             gfObject)
-
-      entry._delete_handler = entry.connect ('delete-text',
-                                             self.deleteTextHandler,
-                                             gfObject)
-      entry.connect ('button-release-event', self._buttonRelease)
-
-    return newWidget
-
-
   # ---------------------------------------------------------------------------
   #
   # ---------------------------------------------------------------------------
@@ -139,6 +100,10 @@ class UIEntry (UIHelper):
                                              gfObject)
       entry.connect ('button-release-event', self._buttonRelease)
 
+    newWidget._sfc_handler = newWidget.connect ('set-focus-child',
+                                                self._setFocusChild,
+                                                gfObject)
+
     return newWidget
 
 
@@ -183,7 +148,7 @@ class UIEntry (UIHelper):
   def __createTextView (self, gfObject, event):
 
     newWidget = gtk.TextView ()
-    newWidget.set_wrap_mode (gtk.WRAP_CHAR)
+    # newWidget.set_wrap_mode (gtk.WRAP_CHAR)
     newWidget.set_pixels_above_lines (2)
     newWidget.set_left_margin (2)
 
@@ -191,7 +156,8 @@ class UIEntry (UIHelper):
       newWidget.set_editable (False)
 
     viewport  = gtk.ScrolledWindow ()
-    viewport.add_with_viewport (newWidget)
+    viewport.set_shadow_type (gtk.SHADOW_IN)
+    viewport.add (newWidget)
     viewport.set_policy (gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
     viewport.set_size_request (self.itemWidth, self.itemHeight)
 
@@ -218,7 +184,6 @@ class UIEntry (UIHelper):
     return newWidget
 
 
-
   # ---------------------------------------------------------------------------
   # Create a new text entry widget
   # ---------------------------------------------------------------------------
@@ -251,26 +216,25 @@ class UIEntry (UIHelper):
 
   # ---------------------------------------------------------------------------
   # Set the cursor position in a widget to position
-  # -------------------------------------------------------------------------
+  # ---------------------------------------------------------------------------
 
   def setCursorPosition (self, position, index = 0):
+
     widget = self.widgets [index]
 
-    if self.__isCombo (widget):
-      entry = isinstance (widget, gtk.Combo) and widget.entry or widget.child
-    else:
-      entry = widget
+    entry = isinstance (widget, gtk.ComboBox) and widget.child or widget
 
-    gDebug (6, "setCursorPosition to %s in %s [%s] (%s)" % \
+    assert gDebug (6, "setCursorPosition to %s in %s [%s] (%s)" % \
         (position, entry, index, widget))
 
     if isinstance (entry, gtk.Entry):
       entry.set_position (position)
 
     elif isinstance (entry, gtk.TextView):
+      entry.set_cursor_visible (True)
+
       tBuffer = widget.get_buffer ()
       tBuffer.place_cursor (tBuffer.get_iter_at_offset (position))
-      entry.set_cursor_visible (True)
       entry.scroll_mark_onscreen (tBuffer.get_insert ())
 
 
@@ -280,7 +244,7 @@ class UIEntry (UIHelper):
 
   def setSelectedArea (self, selection1, selection2, index = 0):
 
-    gDebug (6, "Set Selected Area %s/%s in %s [%s]" % \
+    assert gDebug (6, "Set Selected Area %s/%s in %s [%s]" % \
         (selection1, selection2, self, index))
 
     widget = self.widgets [index]
@@ -298,10 +262,8 @@ class UIEntry (UIHelper):
       tBuffer.move_mark (insert, tBuffer.get_iter_at_offset (left))
       tBuffer.move_mark (selbound, tBuffer.get_iter_at_offset (right))
 
-    elif self.__isCombo (widget):
-      entry = isinstance (widget, gtk.Combo) and widget.entry or widget.child
-      entry.select_region (selection1, selection2)
-
+    elif isinstance (widget, gtk.ComboBox):
+      widget.child.select_region (selection1, selection2)
 
 
   # ---------------------------------------------------------------------------
@@ -310,7 +272,7 @@ class UIEntry (UIHelper):
 
   def insertTextHandler (self, widget, newtext, length, pos, gfObject):
 
-    gDebug (6, "insert gtk.Entry () '%s' at %d (%s) into %s" % \
+    assert gDebug (6, "insert gtk.Entry () '%s' at %d (%s) into %s" % \
                (newtext, widget.get_position (), pos, widget))
 
     # Before we're going to change the field's value, make sure it has the
@@ -323,7 +285,7 @@ class UIEntry (UIHelper):
                            _form = gfObject._form)
 
     widget.stop_emission ('insert-text')
-    gtk.idle_add (self._eventHandler, action)
+    gobject.idle_add (self._eventHandler, action)
 
 
   # ---------------------------------------------------------------------------
@@ -332,7 +294,7 @@ class UIEntry (UIHelper):
 
   def deleteTextHandler (self, widget, start_pos, end_pos, gfObject):
 
-    gDebug (6, "Delete %s to %s in %s" % (start_pos, end_pos, widget))
+    assert gDebug (6, "Delete %s to %s in %s" % (start_pos, end_pos, widget))
 
     # Before we're going to change the field's value, make sure it has the
     # focus on both sides (UI and GF)
@@ -355,18 +317,16 @@ class UIEntry (UIHelper):
 
   def insertBufferHandler (self, tBuffer, iterator, newtext, length, widget):
 
-    gDebug (6, "gtk.TextBuffer insert '%s' at %s" % \
-               (newtext, iterator.get_offset ()))
-
+    position = iterator.get_offset ()
     gfObject = self._uiDriver._WidgetToGFObj [widget]
+
+    assert gDebug (6, "gtk.TextBuffer insert '%s' at %s" % \
+               (newtext, position))
+
     text = unicode (newtext, 'utf-8')
-
-    action = events.Event ('requestINSERTAT', text, text = text,
-                           position = iterator.get_offset (),
-                           _form = gfObject._form)
-
     tBuffer.stop_emission ('insert-text')
-    self._eventHandler (action)
+
+    self._request ('INSERTAT', text = text, position = position)
 
 
   # ---------------------------------------------------------------------------
@@ -375,7 +335,7 @@ class UIEntry (UIHelper):
 
   def deleteBufferHandler (self, tBuffer, start, end, widget):
 
-    gDebug (6, "gtk.TextBuffer delete %s to %s in %s" \
+    assert gDebug (6, "gtk.TextBuffer delete %s to %s in %s" \
                 % (start.get_offset (), end.get_offset (), widget))
 
     gfObject = self._uiDriver._WidgetToGFObj [widget]
@@ -404,25 +364,21 @@ class UIEntry (UIHelper):
     if event.keyval == gtk.keysyms.Down:
       tBuffer = widget.get_buffer ()
 
-      currLine = tBuffer.get_iter_at_mark (tBuffer.get_insert ()).get_line ()
-      lastLine = tBuffer.get_end_iter ().get_line ()
-
-      if currLine != lastLine:
-        tBuffer.place_cursor (tBuffer.get_iter_at_line (currLine + 1))
+      cIter = tBuffer.get_iter_at_mark (tBuffer.get_insert ())
+      if widget.forward_display_line (cIter):
+        self._request ('CURSORMOVE', position = cIter.get_offset ())
       else:
-        widget.get_toplevel ().child_focus (gtk.DIR_TAB_FORWARD)
+        self._request ('NEXTENTRY')
 
       return True
 
     elif event.keyval == gtk.keysyms.Up:
       tBuffer = widget.get_buffer ()
-      currLine = tBuffer.get_iter_at_mark (tBuffer.get_insert ()).get_line ()
-
-      if currLine > 0:
-        tBuffer.place_cursor (tBuffer.get_iter_at_line (currLine - 1))
-
+      cIter = tBuffer.get_iter_at_mark (tBuffer.get_insert ())
+      if widget.backward_display_line (cIter):
+        self._request ('CURSORMOVE', position = cIter.get_offset ())
       else:
-        widget.get_toplevel ().child_focus (gtk.DIR_TAB_BACKWARD)
+        self._request ('PREVENTRY')
 
       return True
 
@@ -459,18 +415,15 @@ class UIEntry (UIHelper):
 
   def _updateChoices (self, widget, gfObject):
 
-    if self.__isCombo (widget):
+    if isinstance (widget, gtk.ComboBox):
       if widget._origAllowedValues != gfObject._field._allowedValues:
         (self.reverse, self.choices) = gfObject._field.allowedValues ()
         self.choices.sort ()
 
         widget._origAllowedValues = gfObject._field._allowedValues
 
-        if self._useNewGTKAPI:
-          widget.get_model ().clear ()
-          map (widget.append_text, self.choices)
-        else:
-          widget.set_popdown_strings (self.choices)
+        widget.get_model ().clear ()
+        map (widget.append_text, self.choices)
 
     elif isinstance (widget, gtk.TreeView):
       if widget._origAllowedValues != gfObject._field._allowedValues:
@@ -571,7 +524,7 @@ class UIEntry (UIHelper):
 
   def _focusOnScroll (self, adjustment, treeView):
 
-    gDebug (6, "grabing focus to %s on adjustment-change %s" % (treeView,
+    assert gDebug (6, "grabing focus to %s on adjustment-change %s" % (treeView,
                                                                 adjustment))
     self._blockHandler (treeView, '_focusHandler')
     treeView.grab_focus ()
@@ -601,7 +554,7 @@ class UIEntry (UIHelper):
       cPos   = widget.get_position ()
       bounds = widget.get_selection_bounds ()
 
-    gDebug (6, "Button-Release: %s (%s) %s %s" % (widget, self._gfObject.name,
+    assert gDebug (6, "Button-Release: %s (%s) %s %s" % (widget, self._gfObject.name,
                                                   cPos, bounds))
     if len (bounds):
       self._request ('SELECTWITHMOUSE', position1 = bounds [0],
@@ -611,13 +564,20 @@ class UIEntry (UIHelper):
 
 
   # ---------------------------------------------------------------------------
-  # Check if a widget is a drop down
+  # Set the focus child for a combo box entry
   # ---------------------------------------------------------------------------
 
-  def __isCombo (self, widget):
+  def _setFocusChild (self, widget, child, gfObject):
 
-    return isinstance (widget, gtk.Combo) or \
-        (self._useNewGTKAPI and isinstance (widget, gtk.ComboBox))
+    self._blockHandler (widget, '_sfc_handler')
+
+    if child is not None:
+      # Move the focus to the entry of the dropdown. This implies a
+      # focus-change in the GF-layer too
+      if not widget.is_focus ():
+        widget.child.grab_focus ()
+
+    self._blockHandler (widget, '_sfc_handler', True)
 
 
 # -----------------------------------------------------------------------------
@@ -633,20 +593,15 @@ def size_request ():
 
   e = gtk.Entry ()
   (w, eHeight) = e.size_request ()
-  if gtk.pygtk_version < (2, 4, 0):
-    c = gtk.Combo ()
-  else:
-    c = gtk.ComboBoxEntry ()
-  (w, cHeight) = e.size_request ()
+  c = gtk.ComboBoxEntry ()
+  (w, cHeight) = c.size_request ()
 
   return (None, max (eHeight, cHeight))
 
 
-
-
-# -----------------------------------------------------------------------------
+# =============================================================================
 # Base configuration data
-# -----------------------------------------------------------------------------
+# =============================================================================
 
 configuration = {
     'baseClass'  : UIEntry,
