@@ -19,7 +19,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: wrappers.py 7008 2005-02-11 17:03:06Z reinhard $
+# $Id: wrappers.py 7898 2005-09-12 14:31:40Z jamest $
 
 import gtk
 
@@ -177,7 +177,7 @@ class TabbedWrapper (gtk.Notebook):
 
   def createPage (self, gfObject):
 
-    gDebug (6, "createPage %s for %s" % (self, gfObject))
+    assert gDebug (6, "createPage %s for %s" % (self, gfObject))
     newWidget = gtk.Fixed ()
     swin = gtk.ScrolledWindow ()
 
@@ -209,7 +209,7 @@ class TabbedWrapper (gtk.Notebook):
 
   def notebookTabHandler (self, notebook, notebookpage, pageNr):
 
-    gDebug (6, "switch-page %s %s %s" % (pageNr, self._oldpage, notebook))
+    assert gDebug (6, "switch-page %s %s %s" % (pageNr, self._oldpage, notebook))
 
     if self._oldpage != pageNr:
       action = events.Event ('requestPAGE', pageNr, _form = self.form)
@@ -223,7 +223,7 @@ class TabbedWrapper (gtk.Notebook):
   # ---------------------------------------------------------------------------
 
   def setPage (self, page):
-    gDebug (6, "SET-PAGE %s to %s" % (self, page))
+    assert gDebug (6, "SET-PAGE %s to %s" % (self, page))
 
     swin = page.get_parent ().get_parent ()
     pageNum = self.page_num (swin)
