@@ -19,7 +19,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: scrollbar.py 7008 2005-02-11 17:03:06Z reinhard $
+# $Id: scrollbar.py 7954 2005-09-21 18:10:06Z reinhard $
 
 import gtk
 
@@ -38,53 +38,50 @@ class UIScrollBar (UIHelper):
 
   def _createWidget (self, event, spacer):
     gfObject = event.object
-    gfBlock  = gfObject._block
 
-    self.adjustment = gtk.Adjustment (1, 1, gfBlock._recordCount, 1)
+    (crec, recs, page) = gfObject.getRecordAndPageCount ()
+
+    self.adjustment = gtk.Adjustment (crec, 0, recs - 1, 1, page - 1, page - 1)
 
     newWidget = gtk.VScrollbar (self.adjustment)
     height    = gfObject.Char__height * event.widgetHeight
     newWidget.set_size_request (-1, height)
+
     self.adjustment._scrollHandler = self.adjustment.connect ('value-changed',
-                                                self._scrollHandler, gfObject)
+                                                self._scrollHandler)
     
     event.container.put (newWidget, self.itemX, self.itemY)
     newWidget.show ()
 
-    gfBlock.registerScrollbar (self)
-    
     return newWidget
 
 
-  # ---------------------------------------------------------------------------
-  # Handle changes of the adjustment's value
-  # ---------------------------------------------------------------------------
-
-  def _scrollHandler (self, adjustment, gfObject):
-
-    gDebug (6, "Adjust to %s" % (int (adjustment.value)))
-    action = events.Event ('requestRECORDNUMBER', int (adjustment.value),
-                           _form = gfObject._form)
-    adjustment.stop_emission ('value-changed')
-    gtk.idle_add (self._eventHandler, action)
-
-    return True
-
-
   # ---------------------------------------------------------------------------
   # adjust the scrollbar to a new position
   # ---------------------------------------------------------------------------
 
   def adjustScrollbar (self, position, count):
-    if int (self.adjustment.upper) != count:
-      self.adjustment.upper = float (count)
 
-    newPos = position + 1
+    if int (self.adjustment.upper) != count - 1:
+      self.adjustment.upper = float (count - 1)
+
     self._blockHandler (self.adjustment, '_scrollHandler')
-    self.adjustment.set_value (newPos)
+    self.adjustment.set_value (position)
     self._blockHandler (self.adjustment, '_scrollHandler', True)
 
 
+  # ---------------------------------------------------------------------------
+  # Handle changes of the adjustment's value
+  # ---------------------------------------------------------------------------
+
+  def _scrollHandler (self, adjustment):
+
+    assert gDebug (6, "Adjust to %s" % int (adjustment.value))
+    self._gfObject.scrollToRecord (int (adjustment.value))
+
+    return True
+
+
 # -----------------------------------------------------------------------------
 # Configuration data
 # -----------------------------------------------------------------------------
