@@ -51,7 +51,7 @@ class ToolBar(_BaseToolBar):
         icon = QIconSet(QPixmap(iconloc))
         _cachedIcons[iconloc] = icon
         if grayloc:
-          icon.setPixmap(QPixmap(grayloc), QIconSet.Normal, QIconSet.Disabled)
+          icon.setPixmap(QPixmap(grayloc), QIconSet.Automatic, QIconSet.Normal, QIconSet.Off)
         else:
           print "** WARNING: No gray version of '%s' to toolbar; no icon" % userAction.event
 
