@@ -61,6 +61,14 @@ from common import *
 # All UIs must provide this class
 #
 class GFUserInterface(commonToolkit.GFUserInterface):
+  _MBOX_KIND = {'Info'    : {'style': QMessageBox.information,
+                                 'title': _("Information")},
+                'Warning' : {'style': QMessageBox.warning,
+                             'title': _("Warning")},
+                'Question': {'style': QInputDialog.getText,
+                             'title': _("Question")},
+                'Error'   : {'style': QMessageBox.critical,
+                             'title': _("Error")}}
 
   def initialize(self):
 
@@ -112,10 +120,17 @@ class GFUserInterface(commonToolkit.GFUserInterface):
     maxDescent = fm.descent()
     maxLeading = fm.leading()
 
-    self.textWidth    = int(maxWidth+maxLeading)  # The pixel width of text inside a widget
-    self.textHeight   = int(maxHeight+maxDescent) # The pixel height of text inside a widget
-    self.widgetWidth  = self.textWidth            # The pixel width of a 1 char widget (for things like buttons)
-    self.widgetHeight = self.textHeight + 4       # The pixel height of a 1 char widget (for things like buttons)
+    # The pixel width of text inside a widget
+    self.textWidth = int(maxWidth+maxLeading)
+    
+    # The pixel height of text inside a widget
+    self.textHeight = int(maxHeight+maxDescent)
+    
+    # The pixel width of a 1 char widget (for things like buttons)
+    self.widgetWidth = self.textWidth
+    
+    # The pixel height of a 1 char widget (for things like buttons)
+    self.widgetHeight = self.textHeight + 4
 
 
 
@@ -133,7 +148,7 @@ class GFUserInterface(commonToolkit.GFUserInterface):
   # Tells the application to close it's main window
   #
   def _exit(self, formName):
-    exitApp = 1
+    exitApp = True
     for child in self._children:
       if child._form.name == formName:
         child.mainWindow.hide()
@@ -142,7 +157,7 @@ class GFUserInterface(commonToolkit.GFUserInterface):
 
     if exitApp:
       for child in self._children:
-        child.mainWindow.close(1)
+        child.mainWindow.close(True)
 
 
 
@@ -179,7 +194,6 @@ class GFUserInterface(commonToolkit.GFUserInterface):
   def endWait (self, event):
     self._qtapp.restoreOverrideCursor()
 
-
   #
   # Clipboard routines
   #
@@ -201,7 +215,6 @@ class GFUserInterface(commonToolkit.GFUserInterface):
   #
   # Processes the events from the widget set
   #
-
   #
   # closeTrap
   #
@@ -215,5 +228,15 @@ class GFUserInterface(commonToolkit.GFUserInterface):
     else:
       object = _eventObjToQtWindow(event)
       object.Destroy()
-      # wxExit() TODO: Try and work this into navigator or here if it still hangs
+  
+  def _showMessage (self, message, kind = 'Info', title = None, cancel = False):
+
+    boxClass = self._MBOX_KIND [kind]['style']
+
+    if title is None:
+      title = self._MBOX_KIND [kind]['title']
+    result = boxClass (None, title, lineWrap(message,80))
+
+  def _showException (self, group, name, message, detail):
+    self._showMessage (detail, 'Error')
 
