@@ -17,7 +17,7 @@
 #
 # Copyright 2000-2005 Free Software Foundation
 #
-# $Id: GFwin32App.py 7008 2005-02-11 17:03:06Z reinhard $
+# $Id: GFwin32App.py 7657 2005-06-26 11:09:49Z btami $
 #
 # DESCRIPTION:
 # A PyWin32 based user interface driver for GNUe forms.
@@ -25,7 +25,7 @@
 # NOTES:
 #
 
-import win32gui, win32con
+import win32gui
 
 __win32App = None
 
