@@ -17,7 +17,7 @@
 #
 # Copyright 2000-2005 Free Software Foundation
 #
-# $Id: UIdriver.py 7659 2005-06-26 16:05:08Z btami $
+# $Id: UIdriver.py 7925 2005-09-20 08:03:35Z btami $
 #
 # DESCRIPTION:
 # A PyWin32 based user interface driver for GNUe forms.
@@ -51,7 +51,7 @@ from gnue.forms.uidrivers._commonGuiToolkit import UIdriver as commonToolkit
 from gnue.forms.uidrivers.win32.GFwin32App import *
 #from gnue.forms.uidrivers.wx.UIWXSplashScreen import *
 from gnue.forms.uidrivers.win32.widgets._base  import *
-from gnue.forms.uidrivers.win32.common import textEncode
+from gnue.forms.uidrivers.win32.common import textEncode, textDecode
 from gnue.forms.uidrivers.win32.dialog import BaseDialog
 from gnue.forms.uidrivers.win32 import dialogs
 
@@ -295,7 +295,7 @@ class GFUserInterface(commonToolkit.GFUserInterface):
       GDebug.printMesg(1,'Unable to open clipboard for read')
 
     if success:
-      value = success
+      value = textDecode(success)
     else:
       GDebug.printMesg(1,'Unable to obtain clipboard contents. Defaulting to Empty.')
       value = None
@@ -309,7 +309,7 @@ class GFUserInterface(commonToolkit.GFUserInterface):
 
     if None == win32clipboard.OpenClipboard():
       win32clipboard.EmptyClipboard()
-      handle = win32clipboard.SetClipboardText(event.text)
+      handle = win32clipboard.SetClipboardText(textEncode(event.text))
       GDebug.printMesg(6,"Set Clipboard Data Handle: %s" % handle)
       win32clipboard.CloseClipboard()
     else:
