@@ -17,7 +17,7 @@
 #
 # Copyright 2000-2005 Free Software Foundation
 #
-# $Id: common.py 6851 2005-01-03 20:59:28Z jcater $
+# $Id: common.py 7657 2005-06-26 11:09:49Z btami $
 #
 # DESCRIPTION:
 # A PyWin32 based user interface driver for GNUe forms.
@@ -25,12 +25,12 @@
 # NOTES:
 #
 
-import string
-import win32gui, win32con, win32ui
-from win32con import *
+from types import UnicodeType, StringType
+
+import win32gui
+
 from gnue.common import events
 from gnue.common.apps import GConfig
-from types import UnicodeType, StringType
 
 
 _idPos = 1000
@@ -46,7 +46,7 @@ def centerWindow(hwnd):
   l,t,r,b = win32gui.GetWindowRect(hwnd)
   dt_l, dt_t, dt_r, dt_b = win32gui.GetWindowRect(desktop)
   center_x, center_y = win32gui.ClientToScreen( desktop, ( (dt_r-dt_l)/2, (dt_b-dt_t)/2) )
-  win32gui.MoveWindow(hwnd, center_x-(r/2), center_y-(b/2), r-l, b-t, 0)
+  win32gui.MoveWindow(hwnd, center_x-(r/2), center_y-(b/2), r-l, b-t, 1)
 
 
 def textEncode(u_string):    
