@@ -17,7 +17,7 @@
 #
 # Copyright 2000-2005 Free Software Foundation
 #
-# $Id: _base.py 7704 2005-07-07 14:53:02Z johannes $
+# $Id: _base.py 8003 2005-09-27 08:51:53Z btami $
 #
 # DESCRIPTION:
 # A PyWin32 based user interface driver for GNUe forms.
@@ -25,7 +25,6 @@
 # NOTES:
 #
 
-import re
 import struct
 
 import win32ui
@@ -49,6 +48,14 @@ except:
 #TCN_SELCHANGE = (commctrl.TCN_FIRST - 1)
 #TCN_SELCHANGING = (commctrl.TCN_FIRST - 2)
 
+# user defined events for edit part of dropdown
+WM_TAB = win32con.WM_USER
+WM_RETURN = win32con.WM_USER + 1
+
+def _MyCallback( hwnd, windows ):
+    windows.append(hwnd)
+
+
 class Win32Base:
   _connectTable = {}
 
@@ -66,7 +73,7 @@ class Win32Base:
       parent._children.append(self)
 
     self._hwnd = win32gui.CreateWindowEx(styleEx, className, windowTitle, style, x,y, width,height, hparent, menu, instance, None)
-
+    
     # this is only for SetFont
     self._PyCWnd = win32ui.CreateWindowFromHandle(self._hwnd)
 
@@ -74,9 +81,64 @@ class Win32Base:
     self._uiDriver._win32app._HwndToTkObj[self._hwnd] = self
 
     if className in ['STATIC', 'BUTTON', 'COMBOBOX', 'LISTBOX', 'EDIT']:
+      # subclassing edit control part of the combo box eventhandler
+      # to produce incremental search/autocomplete
+      if className == 'COMBOBOX':
+        self._AutoComplete = True
+        windows = []
+        try:
+          win32gui.EnumChildWindows(self._hwnd, _MyCallback, windows)
+          self._editHwnd = windows[0]
+          self._oldWndProc1 = win32gui.SetWindowLong(self._editHwnd, win32con.GWL_WNDPROC, self._wndproc1)
+        except:
+          pass
+
       self.Show() 
       self._oldWndProc = win32gui.SetWindowLong(self._hwnd, win32con.GWL_WNDPROC, self._wndproc)
 
+  # edit control part of the combo box eventhandler
+  def _wndproc1(self, hwnd, msg, wParam, lParam):
+    if msg == win32con.WM_LBUTTONDOWN:
+      gfObject = self._uiDriver._IdToGFObj[self._id]
+      uiObject = self._uiDriver._IdToUIObj[self._id]
+
+      uiObject._eventHandler('requestFOCUS',gfObject,_form=gfObject._form)
+      count = uiObject.widgets.index(self)
+      uiObject._eventHandler('requestJUMPRECORD',count - gfObject._visibleIndex,_form=gfObject._form)
+
+    elif msg == win32con.WM_KEYDOWN:
+      keycode = wParam
+      self._AutoComplete = True
+      
+      # let the delete/back keys do their job
+      if keycode in (win32con.VK_DELETE, win32con.VK_BACK):
+        self._AutoComplete = False
+        
+      elif keycode == win32con.VK_TAB:
+        # we have to deal with tab and enter
+        ShiftDown = (win32api.GetKeyState(win32con.VK_SHIFT) & 0x8000) and 1 or 0
+        if ShiftDown:
+          win32gui.SendMessage(self._hwnd, WM_TAB, 0, 1)
+        else:
+          win32gui.SendMessage(self._hwnd, WM_TAB, 0, 0)
+        return 0
+        
+      elif keycode == win32con.VK_RETURN:
+        win32gui.SendMessage(self._hwnd, WM_RETURN, 0, 0)
+        return 0
+        
+      elif keycode in F_KEYS:
+        win32gui.SendMessage(self._hwnd, msg, wParam, lParam)
+        return 0
+
+    elif msg == win32con.WM_CHAR:
+      keycode = wParam
+      if keycode in (win32con.VK_TAB, win32con.VK_RETURN):
+        return 0 
+        
+    return win32gui.CallWindowProc(self._oldWndProc1, hwnd, msg, wParam, lParam)
+
+  # main eventhandler
   def _wndproc(self, hwnd, msg, wParam, lParam):
     if msg == win32con.WM_LBUTTONDOWN:
       gfObject = self._uiDriver._IdToGFObj[self._id]
@@ -98,35 +160,33 @@ class Win32Base:
           cursorPosition = self.getSelectedArea()[1]
           uiObject._request ('CURSORMOVE', position = cursorPosition)
 
-        win32gui.CallWindowProc(self._oldWndProc, hwnd, msg, wParam, lParam)
+        return win32gui.CallWindowProc(self._oldWndProc, hwnd, msg, wParam, lParam)
 
     elif msg == win32con.WM_LBUTTONUP:
       gfObject = self._uiDriver._IdToGFObj[self._id]
       uiObject = self._uiDriver._IdToUIObj[self._id]
 
       if gfObject._type == 'GFEntry' and gfObject.style == 'default':
-        selection1, selection2 = self.getSelectedArea ()
-        value = self.GetValue ()
-
-        left  = selection1 - value [:selection1].count ('\r')
-        right = selection2 - value [:selection2].count ('\r')
-
+        left, right = self.getSelectedArea ()
         if left == right:
           uiObject._request ('CURSORMOVE', position = left)
-
         else:
           uiObject._request ('SELECTWITHMOUSE', position1 = left,
                                                 position2 = right)
           
-      win32gui.CallWindowProc(self._oldWndProc, hwnd, msg, wParam, lParam)
+      return win32gui.CallWindowProc(self._oldWndProc, hwnd, msg, wParam, lParam)
 
     elif msg == win32con.WM_KEYDOWN:
       keycode = wParam
       gfObject = self._uiDriver._IdToGFObj[self._id]
       if (keycode in NOT_WM_CHAR_KEYS):
 
-        if gfObject._type == 'GFButton' or \
-          (gfObject._type == 'GFEntry' and gfObject.style != 'dropdown' and gfObject.style != 'listbox'):
+        if gfObject._type == 'GFEntry' and \
+           gfObject.style in ('dropdown', 'listbox') and \
+           keycode not in F_KEYS:
+          return win32gui.CallWindowProc(self._oldWndProc, hwnd, msg, wParam, lParam)
+
+        else:
           action = None
 
           ShiftDown = (win32api.GetKeyState(win32con.VK_SHIFT) & 0x8000) and 1 or 0
@@ -148,8 +208,8 @@ class Win32Base:
             uiObject = self._uiDriver._IdToUIObj[self._id]
             uiObject._eventHandler(action)
 
-        else:
-          return win32gui.CallWindowProc(self._oldWndProc, hwnd, msg, wParam, lParam)
+          win32gui.SendMessage(hwnd, win32con.EM_SCROLLCARET, 0, 0)
+
 
     elif msg == win32con.WM_CHAR:
       # The TranslateMessage function generates a WM_CHAR message 
@@ -194,7 +254,6 @@ class Win32Base:
           AltDown)
         
       if command == 'NEWLINE':
-        win32gui.SendMessage(hwnd, win32con.EM_LINESCROLL, 1, 0)
         action = events.Event('requestKEYPRESS', '\r\n',
                      text='\r\n',
                      code=10)
@@ -221,22 +280,59 @@ class Win32Base:
         uiObject = self._uiDriver._IdToUIObj[self._id]
         uiObject._eventHandler(action)
 
+      win32gui.SendMessage(hwnd, win32con.EM_SCROLLCARET, 0, 0)
+
       if gfObject._type == 'GFEntry':
-        if gfObject.style == 'dropdown' or gfObject.style == 'listbox':
+        if gfObject.style == 'dropdown' or gfObject.style == 'listbox' or \
+           command == 'NEWLINE':
           return win32gui.CallWindowProc(self._oldWndProc, hwnd, msg, wParam, lParam)
       
     elif msg == win32con.WM_COMMAND:
-      if win32api.HIWORD(wParam) == win32con.CBN_SELCHANGE:
-        gfObject = self._uiDriver._IdToGFObj[self._id]
-        uiObject = self._uiDriver._IdToUIObj[self._id]
-        if gfObject.style == 'dropdown':
+      gfObject = self._uiDriver._IdToGFObj[self._id]
+      uiObject = self._uiDriver._IdToUIObj[self._id]
+      
+      if gfObject.style == 'dropdown':
+        # Autocompletition goes here:
+        # First find if there any element in the dropdown wth prefix matching, then
+        # select it with CB_SELECTSTRING, then
+        # highlight(select) the not typed yet part of the string
+        if win32api.HIWORD(wParam) == win32con.EN_UPDATE and self._AutoComplete:
+             
+          text = win32gui.GetWindowText(hwnd)
+          length = len(text)
+          gs = win32gui.SendMessage(self._editHwnd, win32con.EM_GETSEL, 0, 0)
+          (start, end) = (win32api.LOWORD(gs), win32api.HIWORD(gs))
+          
+          if win32gui.SendMessage(hwnd, win32con.CB_SELECTSTRING, -1, text) == win32con.CB_ERR:
+            win32gui.SetWindowText(self._editHwnd, text)
+
           selection = self.GetValue()
-          string = gfObject._field.allowedValues()[1][selection]
-          uiObject._eventHandler('requestREPLACEVALUE',object=gfObject,
+          if selection >= 0:
+            string = gfObject._field.allowedValues()[1][selection]
+            uiObject._eventHandler('requestREPLACEVALUE',object=gfObject,
                               index=selection, text=string,
                             _form=gfObject._form)
+
+          if end < length:
+            win32gui.SendMessage(self._editHwnd, win32con.EM_SETSEL, start, end)
+          else:
+            win32gui.SendMessage(self._editHwnd, win32con.EM_SETSEL, length, -1)
+
+        # selection from listbox part of dropdown with mouse or arrows
+        elif win32api.HIWORD(wParam) == win32con.CBN_SELCHANGE:
+          selection = self.GetValue()
+          if selection >= 0:
+            string = gfObject._field.allowedValues()[1][selection]
+            uiObject._eventHandler('requestREPLACEVALUE',object=gfObject,
+                              index=selection, text=string,
+                            _form=gfObject._form)
+          return win32gui.CallWindowProc(self._oldWndProc, hwnd, msg, wParam, lParam)
+        else:
+          return win32gui.CallWindowProc(self._oldWndProc, hwnd, msg, wParam, lParam)
+      else:
         return win32gui.CallWindowProc(self._oldWndProc, hwnd, msg, wParam, lParam)
 
+
     elif msg == win32con.WM_PAINT:
       try:
         gfObject = self._uiDriver._IdToGFObj[self._id]
@@ -251,9 +347,33 @@ class Win32Base:
       else:
         return win32gui.CallWindowProc(self._oldWndProc, hwnd, msg, wParam, lParam)
 
+    # user defined events for edit part of dropdown
+    elif msg == WM_TAB or msg == WM_RETURN:
+      gfObject = self._uiDriver._IdToGFObj[self._id]
+      uiObject = self._uiDriver._IdToUIObj[self._id]
+
+      text = win32gui.GetWindowText(hwnd)
+      win32gui.SendMessage(hwnd, win32con.CB_SELECTSTRING, -1, text)
+      
+      selection = self.GetValue()
+      if selection == -1:
+        selection = 0
+        
+      string = gfObject._field.allowedValues()[1][selection]
+      uiObject._eventHandler('requestREPLACEVALUE',object=gfObject,
+                          index=selection, text=string,
+                        _form=gfObject._form)
+      if lParam == 1:
+        action = events.Event('requestPREVENTRY')
+      else:
+        action = events.Event('requestNEXTENTRY')
+      action.__dict__.update({'_form':gfObject._form})
+      uiObject._eventHandler(action)
+
     else:
       return win32gui.CallWindowProc(self._oldWndProc, hwnd, msg, wParam, lParam)
 
+
   def SetFont(self, font):
       self._PyCWnd.SetFont(font,1)
 
@@ -399,22 +519,9 @@ class Win32Entry(Win32Base):
       return win32gui.GetWindowText(self._hwnd)
 
   def setCursorPosition(self, position):
-    gfObject = self._uiDriver._IdToGFObj[self._id]
-    if gfObject._type == 'GFEntry' and gfObject.style == 'default':
-      value = gfObject.getValue ()
-      if isinstance (value, basestring):
-        part  = value [:position]
-        position = position + part.count ('\n')
     win32gui.SendMessage(self._hwnd, win32con.EM_SETSEL, position, position)
 
   def setSelectedArea(self, selection1, selection2):
-    gfObject = self._uiDriver._IdToGFObj[self._id]
-    if gfObject._type == 'GFEntry' and gfObject.style == 'default':
-      value = gfObject.getValue ()
-      if isinstance (value, basestring):
-        selection1 = selection1 + value [:selection1].count ('\n')
-        selection2 = selection2 + value [:selection2].count ('\n')
-
     win32gui.SendMessage(self._hwnd, win32con.EM_SETSEL, selection1, selection2)
 
   def getSelectedArea(self):
@@ -457,28 +564,31 @@ class Win32Page(Win32Base):
 
     if scrollCode == win32con.SB_THUMBTRACK:
       format = "IIiiIii"
-      size = struct.calcsize(format)
-      scrollinfo = struct.pack(format, size, win32con.SIF_ALL, 0, 0, 0, 0, 0)
+      size = struct.calcsize (format)
+      scrollinfo = struct.pack (format, size, win32con.SIF_ALL, 0, 0, 0, 0, 0)
       win32gui.SendMessage(lParam, win32con.SBM_GETSCROLLINFO, 0, scrollinfo)
-      size, mask, min, max, page, pos, trackpos = struct.unpack(format, scrollinfo)
-      recno = int(trackpos)+1
-      action = events.Event('requestRECORDNUMBER',object=gfObject,
-                            data=recno,
-                          _form=gfObject._form)
+      size, mask, min, max, page, pos, trackpos = struct.unpack (format,
+          scrollinfo)
+      gfObject.scrollToRecord (int (trackpos))
+
+    elif scrollCode == win32con.SB_PAGEUP:
+      gfObject.scrollRecords (- uiObject.pageSize)
+
     elif scrollCode == win32con.SB_PAGEDOWN:
-      action = events.Event('requestJUMPROWSDOWN',object=gfObject, _form=gfObject._form)
-    elif scrollCode == win32con.SB_PAGEUP:
-      action = events.Event('requestJUMPROWSUP',object=gfObject, _form=gfObject._form)
+      gfObject.scrollRecords (uiObject.pageSize)
+
     elif scrollCode == win32con.SB_LINEDOWN:
-      action = events.Event('requestNEXTRECORD',object=gfObject, _form=gfObject._form)
+      gfObject.scrollRecords (1)
+
     elif scrollCode == win32con.SB_LINEUP:
-      action = events.Event('requestPREVRECORD',object=gfObject, _form=gfObject._form)
+      gfObject.scrollRecords (-1)
+
     elif scrollCode == win32con.SB_BOTTOM:
-      action = events.Event('requestLASTRECORD',object=gfObject, _form=gfObject._form)
+      gfObject.scrollToRecord (uiObject.lastRecord)
+
     elif scrollCode == win32con.SB_TOP:
-      action = events.Event('requestFIRSTRECORD',object=gfObject, _form=gfObject._form)
+      gfObject.scrollToRecord (0)
 
-    uiObject._uiForm._eventHandler(action)
 
 class Win32Image(Win32Base):
     
@@ -631,8 +741,8 @@ class UIHelper(UIWidget):
 ## Keymapper Support
 ##
 #####################################################################
-from gnue.forms import GFKeyMapper
-from gnue.forms.GFKeyMapper import vk
+from gnue.forms.input import GFKeyMapper
+from gnue.forms.input.GFKeyMapper import vk
 
 # Translate from Win32 keystrokes to our virtual keystrokes
 win32KeyTranslations = {
@@ -654,17 +764,7 @@ win32KeyTranslations = {
 
 GFKeyMapper.KeyMapper.setUIKeyMap(win32KeyTranslations)
 
-NOT_WM_CHAR_KEYS =[
-  win32con.VK_HOME,
-  win32con.VK_END,
-  win32con.VK_UP,
-  win32con.VK_DOWN,
-  win32con.VK_RIGHT,
-  win32con.VK_LEFT,
-  win32con.VK_INSERT,
-  win32con.VK_DELETE,
-  win32con.VK_PRIOR,
-  win32con.VK_NEXT,
+F_KEYS = [
   win32con.VK_F1,
   win32con.VK_F2,
   win32con.VK_F3,
@@ -677,3 +777,15 @@ NOT_WM_CHAR_KEYS =[
   win32con.VK_F10,
   win32con.VK_F11,
   win32con.VK_F12]
+
+NOT_WM_CHAR_KEYS =[
+  win32con.VK_HOME,
+  win32con.VK_END,
+  win32con.VK_UP,
+  win32con.VK_DOWN,
+  win32con.VK_RIGHT,
+  win32con.VK_LEFT,
+  win32con.VK_INSERT,
+  win32con.VK_DELETE,
+  win32con.VK_PRIOR,
+  win32con.VK_NEXT] + F_KEYS
