@@ -17,7 +17,7 @@
 #
 # Copyright 2000-2005 Free Software Foundation
 #
-# $Id: button.py 6851 2005-01-03 20:59:28Z jcater $
+# $Id: button.py 7657 2005-06-26 11:09:49Z btami $
 #
 # DESCRIPTION:
 # A PyWin32 based user interface driver for GNUe forms.
@@ -25,7 +25,7 @@
 # NOTES:
 #
 
-import win32gui, win32con
+import win32con
 
 from gnue.common import events
 from gnue.forms.uidrivers.win32.widgets._base import UIHelper, Win32Button
@@ -44,7 +44,7 @@ class UIButton(UIHelper):
     newWidget = Win32Button(self._uiDriver, styleEx, 'BUTTON', textEncode(object.label), style,
                         self.itemX,
                         self.itemY, 
-                        self.itemWidth+4,
+                        self.itemWidth,
                         self.itemHeight+4,
                         event.container, getNextId())
     if event.initialize:
