@@ -17,21 +17,26 @@
 #
 # Copyright 2000-2005 Free Software Foundation
 #
-# $Id: wrappers.py 7008 2005-02-11 17:03:06Z reinhard $
+# $Id: wrappers.py 7657 2005-06-26 11:09:49Z btami $
 #
 # DESCRIPTION:
 # A PyWin32 based user interface driver for GNUe forms.
 #
 # NOTES:
 #
-import string, struct, array
 
-import win32gui, win32con, win32api, commctrl, win32ui
+import array
+import struct
+
+import win32gui
+import win32con
+import win32api
+import commctrl
 
-from gnue.common import events
 from gnue.forms.uidrivers.win32.widgets._base import UIHelper, Win32Window, Win32Page
 from gnue.forms.uidrivers.win32.common import *
 
+
 class ScrollableWrapper(Win32Window): 
   def __init__(self, uiform): 
     self.uiform = uiform
