@@ -1,5 +1,8 @@
+# GNU Enterprise Forms - wx UI Driver - User Interface
 #
-# This file is part of GNU Enterprise.
+# Copyright 2001-2005 Free Software Foundation
+#
+# This file is part of GNU Enterprise
 #
 # GNU Enterprise is free software; you can redistribute it
 # and/or modify it under the terms of the GNU General Public
@@ -16,16 +19,10 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# Copyright 2000-2005 Free Software Foundation
-#
-# DESCRIPTION:
-# A wxPython based user interface driver for GNUe forms.
-#
-# NOTES:
-#
-# $Id: UIdriver.py 7064 2005-02-25 13:55:58Z kilo $
+# $Id: UIdriver.py 7758 2005-07-28 19:51:04Z jamest $
 
-import sys, os
+import sys
+import os
 import string
 
 from gnue.forms.uidrivers._base import Exceptions
@@ -50,19 +47,16 @@ from gnue.forms.uidrivers.wx.GFwxApp import *
 from gnue.forms.uidrivers.wx.UIWXSplashScreen import *
 from gnue.forms.uidrivers.wx.widgets._base  import *
 from gnue.forms.uidrivers.wx.common import _eventObjTowxWindow
+from gnue.forms.uidrivers.wx import dialogs
 from PrintForm import printForm
 
 from common import wxEncode
 
-
-#
-# GFUserInterface
-#
-# The public interface to the User Interface
-# All UIs must provide this class
-#
 class GFUserInterface(commonToolkit.GFUserInterface):
-
+  """
+  The public interface to a GNUe Forms user interface
+  All UI drivers must provide this class
+  """
   _MBOX_KIND = {'Info'    : {'style': wxICON_INFORMATION | wxOK,
                              'title': _("Information")},
                 'Warning' : {'style': wxICON_EXCLAMATION | wxOK,
@@ -83,7 +77,7 @@ class GFUserInterface(commonToolkit.GFUserInterface):
     # WX Specifics
     ################################################################
 
-    self._disabledColour = wxLIGHT_GREY
+##    self._disabledColour = wxLIGHT_GREY
 
     self._wxapp = getWxApp()
 
@@ -162,6 +156,7 @@ class GFUserInterface(commonToolkit.GFUserInterface):
 
   def _beep(self):
     wxBell()
+    wxYield()
 
   #############################################################################
   #
@@ -283,6 +278,35 @@ class GFUserInterface(commonToolkit.GFUserInterface):
       dialog.Destroy ()
 
 
+  # ---------------------------------------------------------------------------
+  # Display an about box
+  # ---------------------------------------------------------------------------
+
+  def _showAbout (self, name, appversion, formversion, author, description):
+    
+    dlg = dialogs.AboutBox (name, appversion, formversion, author, description)
+    try:
+      dlg.ShowModal ()
+
+    finally:
+      dlg.Destroy ()
+
+
+  # ---------------------------------------------------------------------------
+  # Start an input dialog and return the data record or None if cancelled
+  # ---------------------------------------------------------------------------
+
+  def _getInput (self, title, fields, cancel = True):
+
+    dialog = dialogs.InputDialog (title, fields, cancel)
+    try:
+      dialog.ShowModal ()
+      return dialog.inputData
+
+    finally:
+      dialog.Destroy ()
+
+
   # ---------------------------------------------------------------------------
   # Show an exception
   # TODO: please implement a better dialog box, i.e. add a button for
