@@ -109,7 +109,7 @@ def initFont(widget, affectsLayout=1):
   try:
     enc=encodings[gConfigForms('textEncoding')]
   except:
-    gDebug (1, u_('Encoding %s is not supported by the wx UI driver') % \
+    assert gDebug (1, u_('Encoding %s is not supported by the wx UI driver') % \
                           gConfigForms('textEncoding'))
     enc=encodings['iso8859-1']
   
@@ -270,8 +270,8 @@ class keyboardEvtHandler(uiBaseEvtHandler):
 ## Keymapper Support
 ##
 #####################################################################
-from gnue.forms import GFKeyMapper
-from gnue.forms.GFKeyMapper import vk
+from gnue.forms.input import GFKeyMapper
+from gnue.forms.input.GFKeyMapper import vk
 
 # Translate from wx keystrokes to our virtual keystrokes
 wxKeyTranslations = {
