@@ -23,7 +23,7 @@
 #
 # NOTES:
 #
-# $Id: _base.py 6851 2005-01-03 20:59:28Z jcater $
+# $Id: _base.py 7887 2005-09-02 20:23:33Z jamest $
 
 from wxPython.wx import *
 
@@ -170,8 +170,8 @@ class UIHelper(UIWidget):
     # Check if foreign key changed
     object = self._uiDriver._IdToGFObj[widget.GetId()]
     try:
-      if (object.style == "dropdown" or object.style == "listbox") and \
-          not object._field._allowedValues == widget._origAllowedValues:
+      if object.style in ("dropdown","listbox") and \
+         not object._field._allowedValues == widget._origAllowedValues:
         try:
           # Not in wx 2.2.x
           widget.Freeze()
