@@ -23,7 +23,7 @@
 #
 # NOTES:
 #
-# $Id: widget.py 6851 2005-01-03 20:59:28Z jcater $
+# $Id: widget.py 7265 2005-03-26 21:37:40Z jamest $
 
 import string
 
@@ -71,9 +71,9 @@ class UIForm(UIHelper):
     formWidth = int(self._form._layout.Char__width)
     formHeight = int(self._form._layout.Char__height)
     self._visibleSize = wxSize(formWidth * self._uiDriver.widgetWidth,
-                      formHeight * self._uiDriver.widgetHeight)
-    self._formSize = formSize = wxSize(formWidth * self._uiDriver.widgetWidth,
-                      (formHeight + self.menu_sb_space) * self._uiDriver.widgetHeight)
+                               formHeight * self._uiDriver.widgetHeight)
+    self._formSize    = wxSize(formWidth * self._uiDriver.widgetWidth,
+                                (formHeight + self.menu_sb_space) * self._uiDriver.widgetHeight)
 
     # The main frame of this form
     if self._form.style != 'dialog':
@@ -159,6 +159,8 @@ class UIForm(UIHelper):
   def _setStatusBar(self, tip, statusValue, insertValue, currentRecord, maxRecord, currentPage, maxPage):
     """
     Sets statusbar values.
+    
+    
     """
     if not self.statusBar:
       return
