@@ -23,7 +23,7 @@
 #
 # NOTES:
 #
-# $Id: wrappers.py 7008 2005-02-11 17:03:06Z reinhard $
+# $Id: wrappers.py 7589 2005-06-10 18:09:10Z btami $
 
 import string, sys
 from gnue.common import events
@@ -66,7 +66,7 @@ class ScrollableWrapper(wxScrolledWindow):
     formWidth = int(form._layout.Char__width)
     formHeight = int(form._layout.Char__height)
     self.layoutSize = wxSize(formWidth * uiform._uiDriver.widgetWidth,
-                      formHeight * uiform._uiDriver.widgetHeight)
+                      formHeight * uiform._uiDriver.widgetHeight+45)
     self._fitted = 0
     self._pageList = []
 
@@ -130,12 +130,11 @@ class TabbedWrapper(ScrollableWrapper):
   def __init__(self, *args, **parms):
     ScrollableWrapper.__init__(self, *args, **parms)
     tabstyle  = _tabStyles[self.form._layout.tabbed]
-    self.pane = notebook = wxNotebook(self.spacerpane, -1, #wxPoint(6,6),
+    self.pane = notebook = wxNotebook(self.spacerpane, -1, pos=wxPoint(0,0),
                                       style=tabstyle)
-    self.notebooksizer = sizer1 = wxNotebookSizer(notebook)
+    self.notebooksizer = wxNotebookSizer(notebook)
 
     sizer2 = wxBoxSizer(wxVERTICAL)
-    sizer2.Add(self.notebooksizer)
     self.frame.SetAutoLayout(1)
     self.spacerpane.SetSizer(sizer2)
 
@@ -153,7 +152,6 @@ class TabbedWrapper(ScrollableWrapper):
     """
     sizer = wxBoxSizer(wxVERTICAL)
     newWidget = wxPanel(self.pane, -1, size=self.layoutSize)
-    sizer.Add(newWidget, 0, wxCENTER)
     newWidget.SetAutoLayout(1)
     newWidget.SetSizer(sizer)
 
@@ -174,8 +172,6 @@ class TabbedWrapper(ScrollableWrapper):
     """
     if self._fitted: return
 
-    self.notebooksizer.Layout()
-    self.notebooksizer.SetSizeHints(self.pane)
     self.SetClientSize(self.layoutSize)
 
     if not USING_WX_22:
