@@ -23,7 +23,7 @@
 #
 # NOTES:
 #
-# $Id: scrollbar.py 6851 2005-01-03 20:59:28Z jcater $
+# $Id: scrollbar.py 7954 2005-09-21 18:10:06Z reinhard $
 
 from wxPython.wx import *
 
@@ -44,29 +44,30 @@ class UIScrollBar(UIHelper):
   # --------------------------------------------------------------------------
   # Create a scrollbar widget
   # --------------------------------------------------------------------------
-  def _createWidget(self, event, spacer):
+  def _createWidget (self, event, spacer):
     """
     Creates a new wxScrollBar widget.
     """
-    object = event.object
+    gfObject = event.object
 
     itemX =      self.itemX
-    itemY =      (object.Char__y + spacer) * event.widgetHeight
-    itemWidth =  object.Char__width * event.widgetWidth
-    itemHeight = object.Char__height * event.widgetHeight
+    itemY =      (gfObject.Char__y + spacer) * event.widgetHeight
+    itemWidth =  gfObject.Char__width * event.widgetWidth
+    itemHeight = gfObject.Char__height * event.widgetHeight
 
-    newWidget = self._widget = wxScrollBar(event.container, -1,
+    newWidget = self._widget = wxScrollBar (event.container, -1,
                            wxPoint(itemX, itemY),
                            wxSize(itemWidth, itemHeight),
                            wxSB_VERTICAL)
 
     if event.initialize:
       self._eventHandler = event.eventHandler
-      EVT_COMMAND_SCROLL(newWidget, newWidget.GetId(), self.scrollbarHandler)
-      _setDefaultEventHandlers(newWidget, event.eventHandler, event.initialize,self._uiDriver)
+      EVT_COMMAND_SCROLL (newWidget, newWidget.GetId (), self.scrollbarHandler)
+      _setDefaultEventHandlers (newWidget, event.eventHandler,
+          event.initialize,self._uiDriver)
 
-      object._block.registerScrollbar(self)
-      self._rows = object._block._rows
+    (crec, recs, self.pageSize) = gfObject.getRecordAndPageCount ()
+    self.adjustScrollbar (crec, recs)
 
     return newWidget
 
@@ -74,31 +75,26 @@ class UIScrollBar(UIHelper):
   # --------------------------------------------------------------------------
   # Handle scrollbar events
   # --------------------------------------------------------------------------
-  def scrollbarHandler(self, event):
+  def scrollbarHandler (self, event):
     """
     Handles scrollbar events.
     """
     object = _eventObjTowxWindow(event)
-    id = object.GetId()
+    id = object.GetId ()
 
-    value = object.GetThumbPosition()
-    recno = int(value) + 1
-
-    gfObject = self._uiDriver._IdToGFObj[id]
-    action = events.Event('requestRECORDNUMBER', object=gfObject, data=recno,
-                          _form=gfObject._form)
-    self._eventHandler(action)
+    self._gfObject.scrollToRecord (int (object.GetThumbPosition ()))
 
 
   # --------------------------------------------------------------------------
   # Adjusts scrollbar pos and size
   # --------------------------------------------------------------------------
-  def adjustScrollbar(self, pos, range):
+  def adjustScrollbar (self, current, count):
     """
     Adjusts the scrollbar's position and size
     """
+
     # position, thumbSize, range, pageSize, refresh = TRUE
-    self._widget.SetScrollbar(pos, self._rows, range + self._rows - 1, self._rows - 1)
+    self._widget.SetScrollbar (current, self.pageSize, count, self.pageSize - 1)
 
 
 # ----------------------------------------------------------------------------
